package com.common.commonlib.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.navigation.Navigation;

import com.common.commonlib.R;
import com.common.commonlib.utils.DisplayUtils;

public class CommonTitleView extends FrameLayout implements View.OnClickListener {
    private Context mContext;
    private ImageView ivBack;
    private TextView tv_title;
    private ImageView ivAdd;
    private TextView tv_edit;
    private int showStyle;

    private static final int STYLE_LEFT = 1;
    private static final int STYLE_LEFT_MIDDLE = 2;
    private static final int STYLE_LEFT_MIDDLE_RIGHT = 3;
    private static final int STYLE_MIDDLE = 4;
    private static final int STYLE_MIDDLE_RIGHT = 5;
    private static final int STYLE_RIGHT = 6;
    private static final int STYLE_EDIT = 7;
    private String title;
    //是否要固定高度的模式，不受match parent\warp content等影响
    private boolean isFixedHeight;
    //设置固定的高度值,默认是48dp
    private int fixedHeight;

    private static final int DEFAULT_HEIGHT = 48;
    private View rlBackHotZone;
    private View rlAddHotZone;
    private View rlEditZone;

    public CommonTitleView(Context context) {
        this(context, null);
    }

    public CommonTitleView(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CommonTitleView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        mContext = context;
        init(attrs);
    }

    private void init(AttributeSet attrs) {
        initAttrs(attrs);
        LayoutInflater.from(mContext).inflate(R.layout.common_title_view, this, true);
        ivBack = findViewById(R.id.iv_back);
        ivAdd = findViewById(R.id.iv_add);
        tv_title = findViewById(R.id.tv_title);
        rlBackHotZone = findViewById(R.id.rl_back_hot_zone);
        rlAddHotZone = findViewById(R.id.rl_add_hot_zone);
        tv_edit = findViewById(R.id.tv_edit);
        rlEditZone = findViewById(R.id.rl_edit_hot_zone);
        initStyle();
        setTitle(title);
    }

    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        if (isFixedHeight) {
            int makeMeasureSpec = MeasureSpec.makeMeasureSpec(fixedHeight, MeasureSpec.EXACTLY);
            super.onMeasure(widthMeasureSpec, makeMeasureSpec);
        } else {
            super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        }
    }

    private void initStyle() {
        switch (showStyle) {
            case STYLE_LEFT:
                ivBack.setVisibility(VISIBLE);
                rlBackHotZone.setOnClickListener(this);
                tv_title.setVisibility(INVISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(INVISIBLE);
                rlAddHotZone.setOnClickListener(null);
                break;
            case STYLE_LEFT_MIDDLE:
                ivBack.setVisibility(VISIBLE);
                rlBackHotZone.setOnClickListener(this);
                tv_title.setVisibility(VISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(INVISIBLE);
                rlAddHotZone.setOnClickListener(null);
                break;
            case STYLE_MIDDLE_RIGHT:
                ivBack.setVisibility(INVISIBLE);
                rlBackHotZone.setOnClickListener(null);
                tv_title.setVisibility(VISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(VISIBLE);
                rlAddHotZone.setOnClickListener(this);
                break;
            case STYLE_RIGHT:
                ivBack.setVisibility(INVISIBLE);
                rlBackHotZone.setOnClickListener(null);
                tv_title.setVisibility(INVISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(VISIBLE);
                rlAddHotZone.setOnClickListener(this);
                break;
            case STYLE_LEFT_MIDDLE_RIGHT:
                ivBack.setVisibility(VISIBLE);
                rlBackHotZone.setOnClickListener(this);
                tv_title.setVisibility(VISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(VISIBLE);
                rlAddHotZone.setOnClickListener(this);
                break;
            case STYLE_EDIT:
                ivBack.setVisibility(VISIBLE);
                rlBackHotZone.setOnClickListener(this);
                tv_title.setVisibility(VISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(GONE);
                rlAddHotZone.setVisibility(GONE);
                rlAddHotZone.setOnClickListener(null);
                tv_edit.setVisibility(VISIBLE);
                rlEditZone.setVisibility(VISIBLE);
                rlEditZone.setOnClickListener(this);
                break;
            case STYLE_MIDDLE:
            default:
                ivBack.setVisibility(INVISIBLE);
                rlBackHotZone.setOnClickListener(null);
                tv_title.setVisibility(VISIBLE);
                tv_title.setText("");
                ivAdd.setVisibility(INVISIBLE);
                rlAddHotZone.setOnClickListener(null);
                break;
        }
    }

    private void initAttrs(AttributeSet attrs) {
        TypedArray typedArray = mContext.obtainStyledAttributes(attrs, R.styleable.CommonTitleView);
        showStyle = typedArray.getInt(R.styleable.CommonTitleView_show_style, STYLE_MIDDLE);
        title = typedArray.getString(R.styleable.CommonTitleView_title);
        isFixedHeight = typedArray.getBoolean(R.styleable.CommonTitleView_is_fixed_height, true);
        fixedHeight = typedArray.getInteger(R.styleable.CommonTitleView_fixed_height, DisplayUtils.INSTANCE.dp2px(mContext, DEFAULT_HEIGHT));

        typedArray.recycle();

    }

    public void setTitle(String title) {
        this.title = title;
        tv_title.setText(title);
    }


    @Override
    public void onClick(View v) {
        int viewId = v.getId();
        if (viewId == R.id.rl_back_hot_zone) {
            if (backButtonListener != null) {
                backButtonListener.onClick();
            } else {
                Navigation.findNavController(this).navigateUp();
            }
        } else if (viewId == R.id.rl_add_hot_zone) {
            if (addListener != null) {
                addListener.onClick();
            }
        } else if (viewId == R.id.rl_edit_hot_zone) {
            if (editListener != null) {
                editListener.onClick();
            }
        }
    }

    public interface BackButtonListener {
        void onClick();
    }

    private BackButtonListener backButtonListener;

    public void setBackButtonListener(BackButtonListener backButtonListener) {
        this.backButtonListener = backButtonListener;
    }

    public interface AddListener {
        void onClick();
    }

    private AddListener addListener;

    public void setAddListener(AddListener addListener) {
        this.addListener = addListener;
    }

    public interface EditListener {
        void onClick();
    }

    private EditListener editListener;

    public void setEditListener(EditListener editListener) {
        this.editListener = editListener;
    }

    public int getEditState() {
        if (tv_edit.getText().equals(mContext.getResources().getString(R.string.edit))) {
            return 0;
        } else if (tv_edit.getText().equals(mContext.getResources().getString(R.string.save))) {
            return 1;
        } else {
            return -1;
        }
    }

    public void setEditText(int state) {
        if (state == 0) {
            tv_edit.setText(mContext.getResources().getString(R.string.edit));
        } else if (state == 1) {
            tv_edit.setText(mContext.getResources().getString(R.string.save));
        } else {
            tv_edit.setText("");
        }
    }
}
